BodyPartSelectorTurnable class

A widget that allows for selecting body parts on a turnable body.

This widget is a wrapper around RotationStage and BodyPartSelector.

Inheritance

Constructors

BodyPartSelectorTurnable({required BodyParts bodyParts, Key? key, ValueChanged<BodyParts>? onSelectionUpdated, bool mirrored = false, Color? selectedColor, Color? unselectedColor, Color? selectedOutlineColor, Color? unselectedOutlineColor, EdgeInsets padding = EdgeInsets.zero, RotationStageLabelData? labelData})
Creates a BodyPartSelectorTurnable.
const

Properties

bodyParts BodyParts
The current selection of body parts
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelData RotationStageLabelData?
The labels for the sides of the RotationStage.
final
mirrored bool
Whether the selection should be mirrored, or symmetric, such that when selecting the left arm for example, the right arm is selected as well.
final
onSelectionUpdated ValueChanged<BodyParts>?
Called when the selection of body parts is updated with the new selection.
final
padding EdgeInsets
The padding around the rendered body.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedColor Color?
The color of the selected body parts.
final
selectedOutlineColor Color?
The color of the outline of the selected body parts.
final
unselectedColor Color?
The color of the unselected body parts.
final
unselectedOutlineColor Color?
The color of the outline of the unselected body parts.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited