BodyParts class

A class representing the different parts of the body that can be selected, and whether they are.

Annotations
  • @freezed

Constructors

BodyParts({@Default.new(false) bool head, @Default.new(false) bool neck, @Default.new(false) bool leftShoulder, @Default.new(false) bool leftUpperArm, @Default.new(false) bool leftElbow, @Default.new(false) bool leftLowerArm, @Default.new(false) bool leftHand, @Default.new(false) bool rightShoulder, @Default.new(false) bool rightUpperArm, @Default.new(false) bool rightElbow, @Default.new(false) bool rightLowerArm, @Default.new(false) bool rightHand, @Default.new(false) bool upperBody, @Default.new(false) bool lowerBody, @Default.new(false) bool leftUpperLeg, @Default.new(false) bool leftKnee, @Default.new(false) bool leftLowerLeg, @Default.new(false) bool leftFoot, @Default.new(false) bool rightUpperLeg, @Default.new(false) bool rightKnee, @Default.new(false) bool rightLowerLeg, @Default.new(false) bool rightFoot, @Default.new(false) bool abdomen, @Default.new(false) bool vestibular})
Creates a new BodyParts object.
const
factory
BodyParts.fromJson(Map<String, dynamic> json)
Creates a new BodyParts object from a JSON object.
factory

Properties

abdomen bool
no setterinherited
copyWith → $BodyPartsCopyWith<BodyParts>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
no setterinherited
leftElbow bool
no setterinherited
leftFoot bool
no setterinherited
leftHand bool
no setterinherited
leftKnee bool
no setterinherited
leftLowerArm bool
no setterinherited
leftLowerLeg bool
no setterinherited
leftShoulder bool
no setterinherited
leftUpperArm bool
no setterinherited
leftUpperLeg bool
no setterinherited
lowerBody bool
no setterinherited
neck bool
no setterinherited
rightElbow bool
no setterinherited
rightFoot bool
no setterinherited
rightHand bool
no setterinherited
rightKnee bool
no setterinherited
rightLowerArm bool
no setterinherited
rightLowerLeg bool
no setterinherited
rightShoulder bool
no setterinherited
rightUpperArm bool
no setterinherited
rightUpperLeg bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upperBody bool
no setterinherited
vestibular bool
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toMap() Map<String, bool>
Returns a Map representation of this object.
toString() String
A string representation of this object.
inherited
withToggledId(String id, {bool mirror = false}) BodyParts
Toggles the BodyPart with the given id.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

all → const BodyParts
A constant representing a selection with all BodyParts selected.