RotationStage class

A widget that allows for rotating a widget with four sides in pseudo-3D, with a bar of handles for switching between the sides.

Combines a RotationStageContent with a RotationStageBar and optional labels for the sides.

The handles will obtain their label from the RotationStageLabels in the widget tree, and if there is none, fall back to english labels.

If you want to customize the labels, wrap the RotationStage in a RotationStageLabels widget with the desired labels.

Inheritance

Constructors

RotationStage({required RotationStageBuilder contentBuilder, RotationStageController? controller, RotationStageBuilder? viewHandleBuilder, double barHeight = 64, bool barInteractable = true, Key? key})
Creates a RotationStage.
const

Properties

barHeight double
The height of the bottom bar in logical pixels.
final
barInteractable bool
Whether the bar is interactable at the moment.
final
contentBuilder RotationStageBuilder
The builder function for the content of the RotationStage.
final
controller RotationStageController?
The controller for the RotationStage.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewHandleBuilder RotationStageBuilder?
The builder function for the handles of the RotationStage.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<RotationStage>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited