RotationStageController class
A controller for the RotationStage.
Wraps a PageController and provides a ValueNotifier for the current page of the RotationStage.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
double> - RotationStageController
Constructors
- RotationStageController({double viewportFraction = 0.2})
- Creates a RotationStageController.
- RotationStageController.customPageController(PageController pageController)
- Creates a RotationStageController with a custom PageController.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- pageController → PageController
-
The PageController instance backing this controller.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ double
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
animateToPage(
int page, {Duration duration = kThemeAnimationDuration, Curve curve = Curves.ease}) → void - Animates the RotationStage to the given page.
-
animateToSide(
RotationStageSide side, {Duration duration = kThemeAnimationDuration, Curve curve = Curves.ease}) → void -
Animates the RotationStage to the closest page that corresponds to the
given
side. -
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited