RotationStageHandle class

A handle for the RotationStage that represents one side of the stage.

The handles will obtain their label from the RotationStageLabels in the widget tree, and if there is none, fall back to english labels.

If you want to customize the labels, wrap the RotationStage in a RotationStageLabels widget with the desired labels.

Inheritance

Constructors

RotationStageHandle({required RotationStageSide side, required bool active, required VoidCallback onTap, required bool backgroundTransparent, Color? activeForegroundColor, Color? inactiveForegroundColor, Color? activeBackgroundColor, Color? inactiveBackgroundColor, Key? key})
Creates a RotationStageHandle.
const

Properties

active bool
Whether this handle is active (the side is currently visible).
final
activeBackgroundColor Color?
The color of the background when the handle is active.
final
activeForegroundColor Color?
The color of the foreground when the handle is active.
final
backgroundTransparent bool
Whether the background of the handle is transparent.
final
hashCode int
The hash code for this object.
no setterinherited
inactiveBackgroundColor Color?
The color of the background when the handle is inactive.
final
inactiveForegroundColor Color?
The color of the foreground when the handle is inactive.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTap VoidCallback
The callback to call when the handle is tapped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
side RotationStageSide
The RotationStageSide to represent.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited