RotationStageSide enum

Represents one of the four sides of the RotationStage.

Values are ordered as if rotating the stage from left to right when looking at it from the front.

Inheritance
Available extensions

Values

front → const RotationStageSide

The front side of the RotationStage.

left → const RotationStageSide

The left side of the RotationStage.

back → const RotationStageSide

The back side of the RotationStage.

The right side of the RotationStage.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<T>({required T front, required T left, required T back, required T right}) → T
Maps the side to a value of type T.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

forIndex(int i) RotationStageSide
Returns the RotationStageSide for the given index.

Constants

values → const List<RotationStageSide>
A constant List of the values in this enum, in order of their declaration.