RotationStageBuilder typedef
RotationStageBuilder =
Widget Function(int index, RotationStageSide side, double currentPage)
The builder function for one side of the RotationStage.
Takes the index of the side, the side itself, and the currentPage of
the stage. The returned widget should be a representation of the side
denoted by side and index.
currentPage is passed to allow for building custom effects based on the
current scroll position, since it can also fall bewtween two pages.
Implementation
typedef RotationStageBuilder = Widget Function(
int index,
RotationStageSide side,
double currentPage,
);